"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.configureStore = configureStore;
exports.store = void 0;
var _redux = require("redux");
var _reduxLogger = _interopRequireDefault(require("redux-logger"));
var _reduxSaga = _interopRequireDefault(require("redux-saga"));
var _reduxThunk = _interopRequireDefault(require("redux-thunk"));
var _sagas = _interopRequireDefault(require("./sagas"));
var _general = _interopRequireDefault(require("./reducers/general"));
var _viewStatus = _interopRequireDefault(require("./reducers/viewStatus"));
var _tabs = _interopRequireDefault(require("./reducers/tabs"));
var _initializer = require("../initializer");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
// import rootReducer from "./reducers";

//import { getNotificationMethod } from "../initializer";
//import { showNotification } from "../config/notifications";

const bindMiddleware = middleware => (0, _redux.applyMiddleware)(...middleware);
const rootReducer = {
  general: _general.default,
  viewStatus: _viewStatus.default,
  tabs: _tabs.default
};
function createReducer(customReducers) {
  return (0, _redux.combineReducers)({
    ...rootReducer,
    ...customReducers
  });
}
function configureStore() {
  let initialState = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  //const showNotification = getNotificationMethod();
  const sagaMiddleware = (0, _reduxSaga.default)({
    onError: error => {
      //showNotification({ message: error.name, description: error.message, type: "error" });
    }
  });
  const middlewares = [_reduxThunk.default, sagaMiddleware];
  if (process.env.NODE_ENV === "development") {
    middlewares.push(_reduxLogger.default);
  }
  const store = (0, _redux.createStore)(createReducer((0, _initializer.getCustomReducers)()), initialState, (0, _redux.compose)(bindMiddleware(middlewares), a => a));
  store.injectReducer = (key, customReducer) => {
    if (!("customReducers" in store)) {
      store.customReducers = {};
    }
    store.customReducers[key] = customReducer;
    store.replaceReducer(createReducer(store.customReducers));
  };
  store.sagaTask = sagaMiddleware.run(_sagas.default);
  return store;
}
const store = exports.store = configureStore();